diff mbox

[PULL,34/73] block: Read only one sector for format probing

Message ID 1418207679-32260-35-git-send-email-kwolf@redhat.com
State New
Headers show

Commit Message

Kevin Wolf Dec. 10, 2014, 10:34 a.m. UTC
The only image format driver that even potentially accesses anything
after 512 bytes in its bdrv_probe() implementation is VMDK, which reads
a plain-text descriptor file. In practice, the field it's looking for
seems to come first and will be well within the first 512 bytes, too.

Signed-off-by: Kevin Wolf <kwolf@redhat.com>
Reviewed-by: Stefan Hajnoczi <stefanha@redhat.com>
Reviewed-by: Max Reitz <mreitz@redhat.com>
Message-id: 1416497234-29880-7-git-send-email-kwolf@redhat.com
Signed-off-by: Stefan Hajnoczi <stefanha@redhat.com>
Signed-off-by: Kevin Wolf <kwolf@redhat.com>
---
 block.c                   | 6 +++---
 include/block/block_int.h | 2 ++
 2 files changed, 5 insertions(+), 3 deletions(-)
diff --git a/include/block/block_int.h b/include/block/block_int.h
index a1c17b9..cd94559 100644
--- a/include/block/block_int.h
+++ b/include/block/block_int.h
@@ -57,6 +57,8 @@ 
 #define BLOCK_OPT_REDUNDANCY        "redundancy"
 #define BLOCK_OPT_NOCOW             "nocow"
 
+#define BLOCK_PROBE_BUF_SIZE        512
+
 typedef struct BdrvTrackedRequest {
     BlockDriverState *bs;
     int64_t offset;
diff mbox

Patch

diff --git a/block.c b/block.c
index aa7edf8..809ec54 100644
--- a/block.c
+++ b/block.c
@@ -654,8 +654,8 @@  BlockDriver *bdrv_find_protocol(const char *filename,
  * we do it anyway for backward compatibility.
  *
  * @buf         contains the image's first @buf_size bytes.
  * @buf_size    is the buffer size in bytes (generally 2048, but can be smaller
  *              if the image file is smaller)
  * @filename    is its filename.
  *
  * For all block drivers, call the bdrv_probe() method to get its
@@ -685,7 +685,7 @@  static int find_image_format(BlockDriverState *bs, const char *filename,
                              BlockDriver **pdrv, Error **errp)
 {
     BlockDriver *drv;
-    uint8_t buf[2048];
+    uint8_t buf[BLOCK_PROBE_BUF_SIZE];
     int ret = 0;
 
     /* Return the raw BlockDriver * to scsi-generic devices or empty drives */
@@ -654,8 +654,8 @@  BlockDriver *bdrv_find_protocol(const char *filename,
  *
  * @buf         contains the image's first @buf_size bytes.
- * @buf_size    is the buffer size in bytes (generally 2048, but can be smaller
- *              if the image file is smaller)
+ * @buf_size    is the buffer size in bytes (generally BLOCK_PROBE_BUF_SIZE,
+ *              but can be smaller if the image file is smaller)
  * @filename    is its filename.
  *